summaryrefslogtreecommitdiffstats
path: root/modules/csv/csv_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'modules/csv/csv_test.go')
-rw-r--r--modules/csv/csv_test.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/modules/csv/csv_test.go b/modules/csv/csv_test.go
index 1612a66953..41c4ddaee2 100644
--- a/modules/csv/csv_test.go
+++ b/modules/csv/csv_test.go
@@ -223,7 +223,7 @@ c;d;#`,
// case 13 - tab delimited with commas in values
{
csv: `name email note
-John Doe john@doe.com This,note,had,a,lot,of,commas,to,test,delimters`,
+John Doe john@doe.com This,note,had,a,lot,of,commas,to,test,delimiters`,
filename: "",
expectedDelimiter: '\t',
},
@@ -240,7 +240,7 @@ func TestRemoveQuotedString(t *testing.T) {
text string
expectedText string
}{
- // case 0 - quoted text with escpaed quotes in 1st column
+ // case 0 - quoted text with escaped quotes in 1st column
{
text: `col1,col2,col3
"quoted ""text"" with
@@ -249,7 +249,7 @@ in first column",b,c`,
expectedText: `col1,col2,col3
,b,c`,
},
- // case 1 - quoted text with escpaed quotes in 2nd column
+ // case 1 - quoted text with escaped quotes in 2nd column
{
text: `col1,col2,col3
a,"quoted ""text"" with
@@ -258,7 +258,7 @@ in second column",c`,
expectedText: `col1,col2,col3
a,,c`,
},
- // case 2 - quoted text with escpaed quotes in last column
+ // case 2 - quoted text with escaped quotes in last column
{
text: `col1,col2,col3
a,b,"quoted ""text"" with
@@ -351,7 +351,7 @@ c;d`,
// case 8 - tab delimited with commas in value
{
csv: `name email note
-John Doe john@doe.com This,note,had,a,lot,of,commas,to,test,delimters`,
+John Doe john@doe.com This,note,had,a,lot,of,commas,to,test,delimiters`,
expectedDelimiter: '\t',
},
// case 9 - tab delimited with new lines in values, commas in values
@@ -431,7 +431,7 @@ skxg,t,vay,d,wug,d,xg,sexc rt g,ag,mjq,fjnyji,iwa,m,ml,b,ua,b,qjxeoc be,s,sh,n,j
csv: "col1@col2@col3\na@b@" + strings.Repeat("c", 6000) + "\nd,e," + strings.Repeat("f", 4000),
expectedDelimiter: '@',
},
// case 16 - has all delimters so should return comma
{
csv: `col1,col2;col3@col4|col5 col6
a b|c@d;e,f`,
@@ -431,7 +431,7 @@ skxg,t,vay,d,wug,d,xg,sexc rt g,ag,mjq,fjnyji,iwa,m,ml,b,ua,b,qjxeoc be,s,sh,n,j
expectedDelimiter: '@',
},
- // case 16 - has all delimters so should return comma
+ // case 16 - has all delimiters so should return comma
{
csv: `col1,col2;col3@col4|col5 col6